@@ -10,6 +10,7 @@ import sys
 import os
 import fcntl
 import time
+import collections
 
 
 def send_wechat(title: str, content: str, token: str, template='txt', channel='wechat'):
@@ -143,8 +144,8 @@ if __name__ == '__main__':
     parser.add_argument('-d', default='', help='命令执行的退出代码')
     parser.add_argument('-s', default='', help='程序开始执行时间, 格式参考 get_time_diff')
     parser.add_argument('-e', default='', help='程序结束执行时间, 格式参考 get_time_diff')
-    args = parser.parse_args()
-    # print(args.c, args.t)
+    args, unknown = parser.parse_known_args()  # 忽略未知参数
+    # print(args, unknown)
     if args.c == '':
         fcntl.fcntl(sys.stdin, fcntl.F_SETFL, os.O_NONBLOCK)
         try:
@@ -154,13 +155,18 @@ if __name__ == '__main__':
             ...
     if args.c == '' or args.t == '':
         sys.exit(0)
+    print('结束执行时间:', args.e, ', 总耗时:', get_time_diff(args.s, args.e), ', 退出代码:', args.d)
+    machine = set_gpu(return_more=True, public_net=True)
     content = {
-        '结束执行时间': args.e,
-        '开始执行时间': args.s,
         '总耗时': get_time_diff(args.s, args.e),
+        '执行目录': os.getcwd(),
+        '开始执行时间': args.s,
+        '结束执行时间': args.e,
         '执行指令': args.c,
-        '命令退出状态': explain_exit_code(args.d),
-        '执行结束后的机器状态(内存单位MB)': {k: '; '.join([str(i) for i in v]) if isinstance(v, list) else v for k, v in set_gpu(return_more=True, public_net=True).items()},
+        '命令退出状态(UNIX信号解释)': explain_exit_code(args.d),
+        '执行结束后的机器状态(mem单位为MB)': {k: '; '.join([str(i) for i in v]) if isinstance(v, list) else v for k, v in machine.items()},
+        '当前环境变量': collections.OrderedDict(sorted(os.environ.items(), key=lambda t: t[0])),
     }
-    ret = send_wechat('ta-{}: '.format(args.d) + args.c[:90], json.dumps(content, ensure_ascii=False, indent=4), args.t)
+    title = '{} {}: {}'.format(machine['hostname'], args.d, args.c)[:100]
+    ret = send_wechat(title, json.dumps(content, ensure_ascii=False, indent=4)[:10000], args.t)
     print('notification:', ret)
